==> vtk6-6.3.0-5-arm.pkg.tar.xz: vtk/vtkQuadraticHexahedron.java <==
// java wrapper for vtkQuadraticHexahedron object
//

package vtk;
import vtk.*;

public class vtkQuadraticHexahedron extends vtkNonLinearCell
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetCellType_2();
  public int GetCellType()
    { return GetCellType_2(); }

  private native int GetCellDimension_3();
  public int GetCellDimension()
    { return GetCellDimension_3(); }

  private native int GetNumberOfEdges_4();
  public int GetNumberOfEdges()
    { return GetNumberOfEdges_4(); }

  private native int GetNumberOfFaces_5();
  public int GetNumberOfFaces()
    { return GetNumberOfFaces_5(); }

  private native long GetEdge_6(int id0);
  public vtkCell GetEdge(int id0) {
    long temp = GetEdge_6(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetFace_7(int id0);
  public vtkCell GetFace(int id0) {
    long temp = GetFace_7(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int CellBoundary_8(int id0,double id1[],vtkIdList id2);
  public int CellBoundary(int id0,double id1[],vtkIdList id2)
    { return CellBoundary_8(id0,id1,id2); }

  private native void Contour_9(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10);
  public void Contour(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10)
    { Contour_9(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10); }

  private native int Triangulate_10(int id0,vtkIdList id1,vtkPoints id2);
  public int Triangulate(int id0,vtkIdList id1,vtkPoints id2)
    { return Triangulate_10(id0,id1,id2); }

  private native void Clip_11(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9);
  public void Clip(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9)
    { Clip_11(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native void InterpolationFunctions_12(double id0[],double id1[]);
  public void InterpolationFunctions(double id0[],double id1[])
    { InterpolationFunctions_12(id0,id1); }

  private native void InterpolationDerivs_13(double id0[],double id1[]);
  public void InterpolationDerivs(double id0[],double id1[])
    { InterpolationDerivs_13(id0,id1); }

  private native void InterpolateFunctions_14(double id0[],double id1[]);
  public void InterpolateFunctions(double id0[],double id1[])
    { InterpolateFunctions_14(id0,id1); }

  private native void InterpolateDerivs_15(double id0[],double id1[]);
  public void InterpolateDerivs(double id0[],double id1[])
    { InterpolateDerivs_15(id0,id1); }

  public vtkQuadraticHexahedron() { super(); }

  public vtkQuadraticHexahedron(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.2-1-arm.pkg.tar.xz: vtk/vtkQuadraticHexahedron.java <==
// java wrapper for vtkQuadraticHexahedron object
//

package vtk;
import vtk.*;

public class vtkQuadraticHexahedron extends vtkNonLinearCell
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetCellType_2();
  public int GetCellType()
    { return GetCellType_2(); }

  private native int GetCellDimension_3();
  public int GetCellDimension()
    { return GetCellDimension_3(); }

  private native int GetNumberOfEdges_4();
  public int GetNumberOfEdges()
    { return GetNumberOfEdges_4(); }

  private native int GetNumberOfFaces_5();
  public int GetNumberOfFaces()
    { return GetNumberOfFaces_5(); }

  private native long GetEdge_6(int id0);
  public vtkCell GetEdge(int id0) {
    long temp = GetEdge_6(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetFace_7(int id0);
  public vtkCell GetFace(int id0) {
    long temp = GetFace_7(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int CellBoundary_8(int id0,double id1[],vtkIdList id2);
  public int CellBoundary(int id0,double id1[],vtkIdList id2)
    { return CellBoundary_8(id0,id1,id2); }

  private native void Contour_9(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10);
  public void Contour(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkCellArray id4,vtkCellArray id5,vtkPointData id6,vtkPointData id7,vtkCellData id8,int id9,vtkCellData id10)
    { Contour_9(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9,id10); }

  private native int Triangulate_10(int id0,vtkIdList id1,vtkPoints id2);
  public int Triangulate(int id0,vtkIdList id1,vtkPoints id2)
    { return Triangulate_10(id0,id1,id2); }

  private native void Clip_11(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9);
  public void Clip(double id0,vtkDataArray id1,vtkIncrementalPointLocator id2,vtkCellArray id3,vtkPointData id4,vtkPointData id5,vtkCellData id6,int id7,vtkCellData id8,int id9)
    { Clip_11(id0,id1,id2,id3,id4,id5,id6,id7,id8,id9); }

  private native void InterpolationFunctions_12(double id0[],double id1[]);
  public void InterpolationFunctions(double id0[],double id1[])
    { InterpolationFunctions_12(id0,id1); }

  private native void InterpolationDerivs_13(double id0[],double id1[]);
  public void InterpolationDerivs(double id0[],double id1[])
    { InterpolationDerivs_13(id0,id1); }

  private native void InterpolateFunctions_14(double id0[],double id1[]);
  public void InterpolateFunctions(double id0[],double id1[])
    { InterpolateFunctions_14(id0,id1); }

  private native void InterpolateDerivs_15(double id0[],double id1[]);
  public void InterpolateDerivs(double id0[],double id1[])
    { InterpolateDerivs_15(id0,id1); }

  public vtkQuadraticHexahedron() { super(); }

  public vtkQuadraticHexahedron(long id) { super(id); }
  public native long   VTKInit();

}
